---
title: Fundamentals of Solara
description: These articles dive deeper into the fundamental aspects of Soalra, like using components, hooks, and managing state.
---
# Fundamentals

If you want to dive deeper into Solara, this section is for you. We will cover the following topics:

  * [Components](/documentation/getting_started/fundamentals/components)
  * Hooks (soon)
  * [State management](/documentation/getting_started/fundamentals/state-management)
